@@ -82,7 +82,7 @@
 #'                     numsells = BSfrequent[,"Sells"])
 #' @export
 
-pin_est <- function(numbuys = NULL, numsells = NULL,
+pin_est <- function(numbuys = NULL, numsells = NULL, nlminb_control = list(),
                     confint = FALSE, ci_control = list(), posterior = TRUE) {
   if(is.null(numbuys)) stop("Missing data for 'numbuys'")
   if(is.null(numsells)) stop("Missing data for 'numsells'")
@@ -93,6 +93,7 @@ pin_est <- function(numbuys = NULL, numsells = NULL,
   res <- pin_est_core(numbuys = numbuys, numsells = numsells,
                       factorization = "Lin_Ke",
                       init_vals = init_vals,
+                      nlminb_control = nlminb_control,
                       confint = confint, ci_control = ci_control,
                       posterior = posterior)
   res
